#!/bin/sh
# Set and adjust the CMOS clock
#
# Version:	@(#)hwclock.sh  2.00  14-Dec-1998  miquels@cistron.nl
#
# Patches:
#		2000-01-30 Henrique M. Holschuh <hmh@rcm.org.br>
#		 - Minor cosmetic changes in an attempt to help new
#		   users notice something IS changing their clocks
#		   during startup/shutdown.
#		 - Added comments to alert users of hwclock issues
#		   and discourage tampering without proper doc reading.

# WARNING:	Please read /usr/share/doc/util-linux/README.Debian.hwclock
#		before changing this file. You risk serious clock
#		misbehaviour otherwise.

# Set this to any options you might need to give to hwclock, such
# as machine hardware clock type for Alphas.
HWCLOCKPARS=

hwclocksh() {
    [ ! -x /sbin/hwclock ] && return 0
    . /etc/default/rcS

    . /lib/lsb/init-functions

    [ "$GMT" = "-u" ] && UTC="yes"
    case "$UTC" in
        no|"")
        	GMT="--localtime"
		    UTC=""
		;;
        yes)
        	GMT="--utc"
		    UTC="--utc"
		;;
        *)
            log_warning_msg "Unknown UTC setting: \"$UTC\""
            return 1
        ;;
    esac

    case "$BADYEAR" in
        no|"")	BADYEAR="" ;;
        yes)	BADYEAR="--badyear" ;;
        *)      log_warning_msg "unknown BADYEAR setting: \"$BADYEAR\""; return 1 ;;
    esac

    case "$1" in
		start)
		    if [ ! -f /etc/adjtime ] && [ ! -e /etc/adjtime ]; then
			    echo "0.0 0 0.0" > /etc/adjtime
		    fi

		    if [ "$HWCLOCKACCESS" != no ]; then
			    log_daemon_msg "Setting the system clock"
	
				# Copies Hardware Clock time to System Clock using the correct
				# timezone for hardware clocks in local time, and sets kernel
				# timezone. DO NOT REMOVE.
				/sbin/hwclock --hctosys $GMT $HWCLOCKPARS $BADYEAR
		        RETOUR=$?
				#	Announce the local time.
				log_progress_msg "`date -R`"
                log_end_msg $RETOUR
		    else
    			log_failure_msg "Not setting System Clock"
		    fi
        ;;
		stop|restart|reload|force-reload)
		    #
		    # Updates the Hardware Clock with the System Clock time.
		    # This will *override* any changes made to the Hardware Clock.
		    #
		    # WARNING: If you disable this, any changes to the system
		    #          clock will not be carried across reboots.
		    #
		    if [ "$HWCLOCKACCESS" != no ]; then
			    log_daemon_msg "Saving the system clock"
			    if [ "$GMT" = "-u" ]; then
			        GMT="--utc"
			    fi
			    /sbin/hwclock --systohc $GMT $HWCLOCKPARS $BADYEAR
                RETOUR=$?
			    log_progress_msg "`date -R`"
                log_end_msg $RETOUR
		    else
			    log_failure_msg "Not saving System Clock"
		    fi
        ;;
		show|status)
		    if [ "$HWCLOCKACCESS" != no ]; then
		    	/sbin/hwclock --show $GMT $HWCLOCKPARS $BADYEAR
		    fi
		    ;;
		*)
		    echo "Usage: hwclock.sh {start|stop|status|reload|force-reload|show}"
		    echo "       start sets kernel (system) clock from hardware (RTC) clock"
		    echo "       stop and reload set hardware (RTC) clock from kernel (system) clock"
		    return 1
		    ;;
    esac
}

hwclocksh "$@"
